#
# spec file for package libolecf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libolecf1
Name:           libolecf
Version:        20240427
Release:        1.2
Summary:        Library and tools to access the OLE 2 Compound File (OLECF) format
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libolecf
Source:         https://github.com/libyal/libolecf/releases/download/%version/%name-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libolecf/releases/download/%version/%name-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source11:       OLE_Compound_File_format.pdf
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfole) >= 20240415
BuildRequires:  pkgconfig(libfvalue) >= 20240415
BuildRequires:  pkgconfig(libfwps) >= 20240415
BuildRequires:  pkgconfig(libuna) >= 20240414
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tools to access the OLE 2 Compound File (OLECF) format.
The OLE 2 Compound File format is used to store certain versions of
Microsoft Office files, thumbs.db and other file formats.

%package -n %lname
Summary:        Library to access the OLE 2 Compound File (OLECF) format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
Library to access the OLE 2 Compound File (OLECF) format. The OLE 2
Compound File format is used to store certain versions of Microsoft
Office files, thumbs.db and other file formats.

%package tools
Summary:        Tools to access the OLE 2 Compound File (OLECF) format
License:        LGPL-3.0-or-later
Group:          System/Filesystems
Requires:       %lname = %version

%description tools
Tools to access the OLE 2 Compound File (OLECF) format. The OLE 2
Compound File format is used to store certain versions of Microsoft
Office files, thumbs.db and other file formats.

%package devel
Summary:        Development files for %name
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libolecf is a library to access the OLE 2 Compound File (OLECF) format.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libolecf.so.*

%files -n %name-tools
%_bindir/olecf*
%_mandir/man1/olecf*.1*

%files -n %name-devel
%doc OLE_Compound_File_format.pdf
%_includedir/libolecf.h
%_includedir/libolecf/
%_libdir/libolecf.so
%_libdir/pkgconfig/libolecf.pc
%_mandir/man3/libolecf.3*

%files %python_files
%license COPYING*
%python_sitearch/pyolecf.so

%changelog
* Sat Apr 27 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240427
  * No changelog was provided
* Mon Feb 12 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240212
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231203
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221024
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables python2 on Leap 15.)
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Switch to curated tarballs
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop python2 module build.
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210512 (381cbe88)
  * No changelog was provided
- Add system-libs.patch
* Wed Dec 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20201004
  * worked on python bindings
- remove BuildRequires:  pkg-config
- add COPYING* to the %%license line
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Allow distros to disable python2 builds (bcond_withou python2):
  Tumbleweed already declares this, as python2 is EOL.
* Wed Apr 15 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- quit using libfdatetime and libfvalue from factory
  * using the factory version causes python-plaso self-test to fail
* Wed Apr  8 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20191221
  * changes for libcdata
  * Worked on mount tool
- rename python-libolecf to python2-libolecf
- add python3-libolecf subproject
- use libfdatetime, libfvalue, libcerror, libcsystem from factory instead of internal version
* Mon Apr  1 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to 20181231
  * Worked on python bindings
  * Changes for get item by path.
  * Worked on olecfinfo
  * changes for libcdata
  * Changes to file name sanitation in export handle
  * removed libcsystem dependency
- removed libcsystem dependency
* Wed Jul 13 2016 Greg.Freemyer@gmail.com
- update to 20160109
  * fixes for rpmbuild
* Tue Jan 26 2016 Greg.Freemyer@gmail.com
- update to v0~20160107
  * worked on Python 3 support
  * 2016 update
- use libcdata from factory, not internal.  Tested via plaso/run_tests.py
- use libcerror internal package.  Build fails with factory version
- use libcstring internal package.  Build fails with factory version
- use libfvalue internal package.  Build fails with factory version
* Sat Jan 23 2016 Greg.Freemyer@gmail.com
- update to v0~20151223
  * worked on format support
  * applied updates
  * worked on Python bindings
  * changed version for pypi repacking
  * worked on setup.py
  * bug fixes after fuzzing with AFL
  * improved support file without directory entries
  * added more bounds checks
- required by plaso v1.4
- update BuildRequires libfvalue to require version 0~20151226
* Wed Jan 14 2015 Greg.Freemyer@gmail.com
- update to v0~20150106
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
  * bug fix in Python-bindings
  * update Python-bindings tests
  * worked on libfwps support
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using new libyal packages from OBS, not internal version
- remove %%if opensuse logic.  Not needed with libyal in security:forensics
* Thu Aug 28 2014 Greg.Freemyer@gmail.com
- use libfdatetime internal package.  With external factory version fails testing.
- use libcdata internal package.  With external factory version fails testing.
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add "Requires:  %%lname = %%version" to tools sub-project
- add "Provice:  pyolecf" to match upstream requires
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- updated to 0~20140801
  * worked on Python bindings
  * bug fix in Python-bindings
  * worked on olecfmount Dokan support
  * updated dependencies
  * small changes to Makefile
  * worked on setup.py
  * 2014 update
- use external package for libfguid
* Sat Nov 23 2013 Greg.Freemyer@gmail.com
- updated to 20131108
  * added support for 0 value sub directory entry not being used as index.
* Wed Oct 16 2013 Greg.Freemyer@gmail.com
- add %%if logic around BuildRequires to allow use of internal packages on older distros
* Wed Oct 16 2013 Greg.Freemyer@gmail.com
- initial package (v0~20131012)
